==> Data-Sah-0.43.tar.gz: Data-Sah-0.43/lib/Data/Sah/Type/float.pm <==
package Data::Sah::Type::float;

use Moo::Role;
use Data::Sah::Util::Role 'has_clause';
with 'Data::Sah::Type::num';

our $VERSION = '0.43'; # VERSION

has_clause 'is_nan',
    tags        => ['constraint'],
    arg         => ['bool'],
    allow_expr  => 1,
    allow_multi => 0,
    ;

has_clause 'is_inf',
    tags        => ['constraint'],
    arg         => ['bool'],
    allow_expr  => 1,
    allow_multi => 1,
    ;

has_clause 'is_pos_inf',
    tags        => ['constraint'],
    arg         => ['bool'],
    allow_expr  => 1,
    allow_multi => 1,
    ;

has_clause 'is_neg_inf',
    tags        => ['constraint'],
    arg         => ['bool'],
    allow_expr  => 1,
    allow_multi => 1,
    ;

1;
# ABSTRACT: float type

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Sah::Type::float - float type

=head1 VERSION

This document describes version 0.43 of Data::Sah::Type::float (from Perl distribution Data-Sah), released on 2015-02-18.

=for Pod::Coverage ^(clause_.+|clausemeta_.+)$

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Data-Sah>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Data-Sah-0.44.tar.gz: Data-Sah-0.44/lib/Data/Sah/Type/float.pm <==
package Data::Sah::Type::float;

use Moo::Role;
use Data::Sah::Util::Role 'has_clause';
with 'Data::Sah::Type::num';

our $VERSION = '0.44'; # VERSION

has_clause 'is_nan',
    tags        => ['constraint'],
    arg         => ['bool'],
    allow_expr  => 1,
    allow_multi => 0,
    ;

has_clause 'is_inf',
    tags        => ['constraint'],
    arg         => ['bool'],
    allow_expr  => 1,
    allow_multi => 1,
    ;

has_clause 'is_pos_inf',
    tags        => ['constraint'],
    arg         => ['bool'],
    allow_expr  => 1,
    allow_multi => 1,
    ;

has_clause 'is_neg_inf',
    tags        => ['constraint'],
    arg         => ['bool'],
    allow_expr  => 1,
    allow_multi => 1,
    ;

1;
# ABSTRACT: float type

__END__

=pod

=encoding UTF-8

=head1 NAME

Data::Sah::Type::float - float type

=head1 VERSION

This document describes version 0.44 of Data::Sah::Type::float (from Perl distribution Data-Sah), released on 2015-02-18.

=for Pod::Coverage ^(clause_.+|clausemeta_.+)$

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Data-Sah>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
